"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Codemod to eject the `classicTheme` object no longer provided in v7
 * ```
 * npx jscodeshift -t node_modules/evergreen-ui/codemods/dist/6.0.0-7.0.0/eject-classic-theme.js --parser=tsx --extensions=js,jsx,ts,tsx fileOrDirectory --dry --print
 * ```
 *
 * This codemod will vendorize a file with the entire `classicTheme` object from Evergreen v6.
 * Make sure you're providing an empty file or a file that you expect to be fully overwritten.
 */
const classicTheme = {
    palette: {
        neutral: {
            lightest: '#F9F9FB',
            light: '#E4E7EB',
            base: '#425A70',
            dark: '#234361'
        },
        blue: {
            lightest: '#f7f9fd',
            light: '#ddebf7',
            base: '#1070ca',
            dark: '#084b8a'
        },
        red: {
            lightest: '#fef6f6',
            light: '#fae2e2',
            base: '#ec4c47',
            dark: '#bf0e08'
        },
        orange: {
            lightest: '#fdf8f3',
            light: '#fae3cd',
            base: '#d9822b',
            dark: '#95591e'
        },
        yellow: {
            lightest: '#fef8e7',
            light: '#fbe6a2',
            base: '#f7d154',
            dark: '#7e6514'
        },
        green: {
            lightest: '#f1faf5',
            light: '#d4eee2',
            base: '#47b881',
            dark: '#00783e'
        },
        teal: {
            lightest: '#f1fbfc',
            light: '#d2eef3',
            base: '#14b5d0',
            dark: '#007489'
        },
        purple: {
            lightest: '#f8f7fc',
            light: '#eae7f8',
            base: '#735dd0',
            dark: '#37248f'
        }
    },
    scales: {
        neutral: {
            N1: '#F9F9FB',
            N2: '#F5F6F7',
            N3: '#EDF0F2',
            N4: '#E4E7EB',
            N5: '#C7CED4',
            N6: '#A6B1BB',
            N7: '#7B8B9A',
            N8: '#66788A',
            N9: '#425A70',
            N10: '#234361',
            N1A: 'rgba(67, 90, 111, 0.04)',
            N2A: 'rgba(67, 90, 111, 0.06)',
            N3A: 'rgba(67, 90, 111, 0.09)',
            N4A: 'rgba(67, 90, 111, 0.14)',
            N5A: 'rgba(67, 90, 111, 0.3)',
            N6A: 'rgba(67, 90, 111, 0.47)',
            N7A: 'rgba(67, 90, 111, 0.7)',
            N8A: 'rgba(67, 90, 111, 0.81)'
        },
        blue: {
            B1: '#f7f9fd',
            B2: '#f1f7fc',
            B3: '#e9f2fa',
            B4: '#ddebf7',
            B5: '#b7d4ef',
            B6: '#8fbce6',
            B7: '#579ad9',
            B8: '#3d8bd4',
            B9: '#1070ca',
            B10: '#084b8a',
            B1A: 'rgba(16, 112, 202, 0.04)',
            B2A: 'rgba(16, 112, 202, 0.06)',
            B3A: 'rgba(16, 112, 202, 0.09)',
            B4A: 'rgba(16, 112, 202, 0.14)',
            B5A: 'rgba(16, 112, 202, 0.3)',
            B6A: 'rgba(16, 112, 202, 0.47)',
            B7A: 'rgba(16, 112, 202, 0.7)',
            B8A: 'rgba(16, 112, 202, 0.81)'
        }
    },
    tokens: {
        colors: {
            gray900: '#101840',
            gray800: '#474d66',
            gray700: '#696f8c',
            gray600: '#8f95b2',
            gray500: '#c1c4d6',
            gray400: '#d8dae5',
            gray300: '#E6E8F0',
            gray200: '#edeff5',
            gray100: '#F4F5F9',
            gray90: '#F4F6FA',
            gray75: '#F9FAFC',
            gray50: '#FAFBFF',
            blue900: '#0A1433',
            blue800: '#142966',
            blue700: '#1F3D99',
            blue600: '#2952CC',
            blue500: '#3366FF',
            blue400: '#5C85FF',
            blue300: '#85A3FF',
            blue200: '#ADC2FF',
            blue100: '#D6E0FF',
            blue50: '#EBF0FF',
            blue25: '#F3F6FF',
            red700: '#7D2828',
            red600: '#A73636',
            red500: '#D14343',
            red100: '#F9DADA',
            red25: '#FDF4F4',
            green900: '#10261E',
            green800: '#214C3C',
            green700: '#317159',
            green600: '#429777',
            green500: '#52BD95',
            green400: '#75CAAA',
            green300: '#97D7BF',
            green200: '#BAE5D5',
            green100: '#DCF2EA',
            green25: '#F5FBF8',
            orange700: '#996A13',
            orange500: '#FFB020',
            orange100: '#F8E3DA',
            orange25: '#FFFAF2',
            purple600: '#6E62B6',
            purple100: '#E7E4F9',
            teal800: '#0F5156',
            teal100: '#D3F5F7',
            yellow800: '#66460D',
            yellow100: '#FFEFD2',
            muted: '#696f8c',
            default: '#474d66'
        },
        fontFamilies: {
            display: '"SF UI Display", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
            ui: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
            mono: '"SF Mono", "Monaco", "Inconsolata", "Fira Mono", "Droid Sans Mono", "Source Code Pro", monospace'
        },
        text: {
            '300': {
                fontSize: '12px',
                fontWeight: 400,
                lineHeight: '16px',
                letterSpacing: '0'
            },
            '400': {
                fontSize: '14px',
                fontWeight: 400,
                lineHeight: '20px',
                letterSpacing: '-0.05px'
            },
            '500': {
                fontSize: '16px',
                fontWeight: 400,
                lineHeight: '20px',
                letterSpacing: '-0.05px'
            },
            '600': {
                fontSize: '20px',
                fontWeight: 400,
                lineHeight: '24px',
                letterSpacing: '-0.07px'
            }
        },
        paragraph: {
            '300': {
                fontSize: '12px',
                fontWeight: 400,
                lineHeight: '18px',
                letterSpacing: '0'
            },
            '400': {
                fontSize: '14px',
                fontWeight: 400,
                lineHeight: '21px',
                letterSpacing: '-0.05px'
            },
            '500': {
                fontSize: '16px',
                fontWeight: 400,
                lineHeight: '24px',
                letterSpacing: '-0.05px'
            }
        },
        overlayBackgroundColor: 'rgba(67, 90, 111, 0.7)',
        codeBackgroundColor: 'rgba(16, 112, 202, 0.06)',
        codeBorderColor: 'rgba(16, 112, 202, 0.14)',
        fills: {
            neutral: {
                color: '#425A70',
                backgroundColor: '#E4E7EB'
            },
            blue: {
                color: '#084b8a',
                backgroundColor: '#ddebf7'
            },
            red: {
                color: '#bf0e08',
                backgroundColor: '#fae2e2'
            },
            orange: {
                color: '#95591e',
                backgroundColor: '#fae3cd'
            },
            yellow: {
                color: '#7e6514',
                backgroundColor: '#fbe6a2'
            },
            green: {
                color: '#00783e',
                backgroundColor: '#d4eee2'
            },
            teal: {
                color: '#007489',
                backgroundColor: '#d2eef3'
            },
            purple: {
                color: '#37248f',
                backgroundColor: '#eae7f8'
            }
        },
        selectedOptionColor: '#3366FF',
        borderRadius: 4,
        primary: {
            base: '#3366FF',
            hover: '#2952CC',
            active: '#1F3D99'
        },
        intents: {
            info: {
                background: '#F3F6FF',
                border: '#3366FF',
                text: '#2952CC',
                icon: '#3366FF'
            },
            success: {
                background: '#F5FBF8',
                border: '#52BD95',
                text: '#317159',
                icon: '#52BD95'
            },
            warning: {
                background: '#FFFAF2',
                border: '#FFB020',
                text: '#996A13',
                icon: '#FFB020'
            },
            danger: {
                background: '#FDF4F4',
                border: '#D14343',
                text: '#A73636',
                icon: '#D14343'
            }
        },
        states: {
            default: {
                icon: '#474d66'
            },
            muted: {
                icon: '#696f8c'
            },
            dark: {
                icon: '#101840'
            },
            disabled: {
                icon: '#c1c4d6'
            },
            selected: {
                icon: '#3366FF'
            }
        }
    },
    colors: {
        neutral: {
            N1: '#F9F9FB',
            N2: '#F5F6F7',
            N3: '#EDF0F2',
            N4: '#E4E7EB',
            N5: '#C7CED4',
            N6: '#A6B1BB',
            N7: '#7B8B9A',
            N8: '#66788A',
            N9: '#425A70',
            N10: '#234361',
            lightest: '#F9F9FB',
            light: '#E4E7EB',
            base: '#425A70',
            dark: '#234361'
        },
        blue: {
            B1: '#f7f9fd',
            B2: '#f1f7fc',
            B3: '#e9f2fa',
            B4: '#ddebf7',
            B5: '#b7d4ef',
            B6: '#8fbce6',
            B7: '#579ad9',
            B8: '#3d8bd4',
            B9: '#1070ca',
            B10: '#084b8a',
            lightest: '#f7f9fd',
            light: '#ddebf7',
            base: '#1070ca',
            dark: '#084b8a'
        },
        red: {
            lightest: '#fef6f6',
            light: '#fae2e2',
            base: '#ec4c47',
            dark: '#bf0e08'
        },
        orange: {
            lightest: '#fdf8f3',
            light: '#fae3cd',
            base: '#d9822b',
            dark: '#95591e'
        },
        yellow: {
            lightest: '#fef8e7',
            light: '#fbe6a2',
            base: '#f7d154',
            dark: '#7e6514'
        },
        green: {
            lightest: '#f1faf5',
            light: '#d4eee2',
            base: '#47b881',
            dark: '#00783e'
        },
        teal: {
            lightest: '#f1fbfc',
            light: '#d2eef3',
            base: '#14b5d0',
            dark: '#007489'
        },
        purple: {
            lightest: '#f8f7fc',
            light: '#eae7f8',
            base: '#735dd0',
            dark: '#37248f'
        },
        neutralAlpha: {
            N1A: 'rgba(67, 90, 111, 0.04)',
            N2A: 'rgba(67, 90, 111, 0.06)',
            N3A: 'rgba(67, 90, 111, 0.09)',
            N4A: 'rgba(67, 90, 111, 0.14)',
            N5A: 'rgba(67, 90, 111, 0.3)',
            N6A: 'rgba(67, 90, 111, 0.47)',
            N7A: 'rgba(67, 90, 111, 0.7)',
            N8A: 'rgba(67, 90, 111, 0.81)'
        },
        blueAlpha: {
            B1A: 'rgba(16, 112, 202, 0.04)',
            B2A: 'rgba(16, 112, 202, 0.06)',
            B3A: 'rgba(16, 112, 202, 0.09)',
            B4A: 'rgba(16, 112, 202, 0.14)',
            B5A: 'rgba(16, 112, 202, 0.3)',
            B6A: 'rgba(16, 112, 202, 0.47)',
            B7A: 'rgba(16, 112, 202, 0.7)',
            B8A: 'rgba(16, 112, 202, 0.81)'
        },
        muted: '#66788A',
        default: '#425A70',
        dark: '#234361',
        selected: '#1070ca',
        tint1: '#F9F9FB',
        tint2: '#F5F6F7',
        overlay: 'rgba(67, 90, 111, 0.7)',
        yellowTint: '#fef8e7',
        greenTint: '#f1faf5',
        orangeTint: '#fdf8f3',
        redTint: '#fef6f6',
        blueTint: '#f7f9fd',
        purpleTint: '#f8f7fc',
        tealTint: '#f1fbfc',
        border: {
            default: '#E4E7EB',
            muted: '#EDF0F2'
        },
        text: {
            success: '#00783e',
            info: '#084b8a',
            danger: '#bf0e08'
        },
        icon: {
            default: '#66788A',
            muted: '#7B8B9A',
            disabled: 'rgba(67, 90, 111, 0.3)',
            selected: '#1070ca'
        }
    },
    fills: {
        solid: {
            neutral: {
                color: 'white',
                backgroundColor: '#425A70'
            },
            blue: {
                color: 'white',
                backgroundColor: '#1070ca'
            },
            red: {
                color: 'white',
                backgroundColor: '#ec4c47'
            },
            orange: {
                color: 'white',
                backgroundColor: '#d9822b'
            },
            yellow: {
                color: '#7e6514',
                backgroundColor: '#f7d154'
            },
            green: {
                color: 'white',
                backgroundColor: '#47b881'
            },
            teal: {
                color: 'white',
                backgroundColor: '#14b5d0'
            },
            purple: {
                color: 'white',
                backgroundColor: '#735dd0'
            }
        },
        subtle: {
            neutral: {
                color: '#234361',
                backgroundColor: '#E4E7EB'
            },
            blue: {
                color: '#084b8a',
                backgroundColor: '#ddebf7'
            },
            red: {
                color: '#bf0e08',
                backgroundColor: '#fae2e2'
            },
            orange: {
                color: '#95591e',
                backgroundColor: '#fae3cd'
            },
            yellow: {
                color: '#7e6514',
                backgroundColor: '#fbe6a2'
            },
            green: {
                color: '#00783e',
                backgroundColor: '#d4eee2'
            },
            teal: {
                color: '#007489',
                backgroundColor: '#d2eef3'
            },
            purple: {
                color: '#37248f',
                backgroundColor: '#eae7f8'
            }
        }
    },
    intents: {
        danger: {
            border: '#ec4c47',
            background: '#ec4c47',
            icon: '#ec4c47'
        },
        warning: {
            border: '#d9822b',
            background: '#d9822b',
            icon: '#d9822b'
        },
        info: {
            border: '#1070ca',
            background: '#1070ca',
            icon: '#1070ca'
        },
        success: {
            border: '#47b881',
            background: '#47b881',
            icon: '#47b881'
        }
    },
    radii: ['0px', '3px', '5px'],
    shadows: [
        '0 0 1px rgba(67, 90, 111, 0.3)',
        '0 0 1px rgba(67, 90, 111, 0.3), 0 2px 4px -2px rgba(67, 90, 111, 0.47)',
        '0 0 1px rgba(67, 90, 111, 0.3), 0 5px 8px -4px rgba(67, 90, 111, 0.47)',
        '0 0 1px rgba(67, 90, 111, 0.3), 0 8px 10px -4px rgba(67, 90, 111, 0.47)',
        '0 0 1px rgba(67, 90, 111, 0.3), 0 16px 24px -8px rgba(67, 90, 111, 0.47)'
    ],
    fontFamilies: {
        display: '"SF UI Display", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
        ui: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
        mono: '"SF Mono", "Monaco", "Inconsolata", "Fira Mono", "Droid Sans Mono", "Source Code Pro", monospace'
    },
    fontSizes: ['11px', '12px', '14px', '16px', '20px', '24px', '29px', '35px'],
    fontWeights: {
        light: 300,
        normal: 400,
        semibold: 500,
        bold: 600
    },
    letterSpacings: {
        tightest: '-0.2px',
        tighter: '-0.07px',
        tight: '-0.05px',
        normal: '0',
        wide: '0.6px'
    },
    lineHeights: ['16px', '18px', '20px', '24px', '28px', '32px', '40px'],
    zIndices: {
        focused: 2,
        stack: 5,
        positioner: 10,
        overlay: 20,
        toaster: 30
    },
    components: {
        Alert: {
            appearances: {
                card: {
                    boxShadow: '0 0 1px rgba(67, 90, 111, 0.3), 0 2px 4px -2px rgba(67, 90, 111, 0.47)',
                    borderRadius: '3px'
                }
            },
            sizes: {}
        },
        Avatar: {
            appearances: {},
            sizes: {}
        },
        Badge: {
            baseStyle: {
                height: 16,
                paddingY: 0,
                paddingX: 6,
                borderRadius: '3px',
                fontSize: '11.5px',
                textAlign: 'center',
                textDecoration: 'none',
                textTransform: 'uppercase'
            },
            appearances: {},
            sizes: {}
        },
        Button: {
            baseStyle: {
                fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                borderRadius: '3px',
                fontWeight: 500,
                border: '0',
                _disabled: {
                    opacity: 0.8,
                    backgroundImage: 'none',
                    backgroundColor: 'rgba(67, 90, 111, 0.06)',
                    boxShadow: 'none',
                    color: 'rgba(67, 90, 111, 0.7)',
                    pointerEvents: 'none'
                }
            },
            appearances: {
                primary: {
                    backgroundColor: 'white',
                    color: 'white',
                    _focus: {},
                    _hover: {},
                    _active: {},
                    _focusAndActive: {}
                },
                default: {
                    backgroundColor: 'white',
                    backgroundImage: 'linear-gradient(to bottom, #FFFFFF, #F4F5F7)',
                    boxShadow: 'inset 0 0 0 1px rgba(67, 90, 111, 0.14), inset 0 -1px 1px 0 rgba(67, 90, 111, 0.06)',
                    _hover: {
                        backgroundImage: 'linear-gradient(to bottom, #FAFBFB, #EAECEE)'
                    },
                    _active: {
                        backgroundImage: 'none',
                        backgroundColor: 'rgba(16, 112, 202, 0.09)',
                        boxShadow: 'inset 0 0 0 1px rgba(67, 90, 111, 0.14), inset 0 1px 1px 0 rgba(67, 90, 111, 0.06)'
                    },
                    _focus: {
                        boxShadow: '0 0 0 3px rgba(16, 112, 202, 0.14), inset 0 0 0 1px rgba(67, 90, 111, 0.3), inset 0 -1px 1px 0 rgba(67, 90, 111, 0.14)'
                    },
                    _disabled: {
                        opacity: 0.8,
                        backgroundImage: 'none',
                        backgroundColor: 'rgba(67, 90, 111, 0.06)',
                        boxShadow: 'none',
                        color: 'rgba(67, 90, 111, 0.7)',
                        pointerEvents: 'none'
                    }
                },
                minimal: {
                    background: 'transparent',
                    _hover: {
                        background: 'rgba(67, 90, 111, 0.06)'
                    },
                    _focus: {},
                    _active: {
                        background: 'rgba(16, 112, 202, 0.09)'
                    }
                }
            },
            sizes: {
                small: {
                    height: 24,
                    minWidth: 24,
                    fontSize: '12px',
                    lineHeight: '24px',
                    paddingLeft: 12,
                    paddingRight: 12
                },
                medium: {
                    height: 32,
                    minWidth: 32,
                    fontSize: '12px',
                    lineHeight: '32px',
                    paddingLeft: 16,
                    paddingRight: 16
                },
                large: {
                    height: 40,
                    minWidth: 40,
                    fontSize: '14px',
                    lineHeight: '40px',
                    paddingLeft: 20,
                    paddingRight: 20
                }
            }
        },
        Card: {
            baseStyle: {
                borderRadius: '3px'
            },
            appearances: {},
            sizes: {}
        },
        Checkbox: {
            baseStyle: {},
            appearances: {
                default: {
                    _base: {
                        color: 'transparent'
                    },
                    _disabled: {
                        cursor: 'not-allowed',
                        background: 'rgba(67, 90, 111, 0.06)'
                    },
                    _hover: {},
                    _focus: {},
                    _active: {
                        background: 'rgba(16, 112, 202, 0.09)'
                    },
                    _checked: {
                        color: 'white',
                        background: 'linear-gradient(to bottom, #0788DE, #116AB8)'
                    },
                    _checkedHover: {
                        color: 'white',
                        background: 'linear-gradient(to bottom, #0679c5, #0f5da1)'
                    },
                    _checkedDisabled: {
                        color: 'rgba(67, 90, 111, 0.47)'
                    },
                    _checkedActive: {
                        color: 'white',
                        background: 'linear-gradient(to bottom, #0f5da1, #0f5da1)'
                    }
                }
            },
            sizes: {}
        },
        Code: {
            baseStyle: {},
            appearances: {
                default: {
                    backgroundColor: 'rgba(16, 112, 202, 0.06)',
                    paddingX: 6,
                    paddingY: 3,
                    borderRadius: '3px'
                }
            },
            sizes: {}
        },
        DialogBody: {
            baseStyle: {
                padding: '16px'
            }
        },
        DialogFooter: {
            baseStyle: {
                padding: '16px',
                borderTop: 'muted'
            }
        },
        DialogHeader: {
            baseStyle: {
                padding: '16px',
                borderBottom: 'muted'
            }
        },
        Group: {
            baseStyle: {
                _child: {
                    '&:focus': {
                        zIndex: 2
                    },
                    '&:active': {
                        zIndex: 2
                    }
                },
                _firstChild: {
                    borderTopRightRadius: 0,
                    borderBottomRightRadius: 0
                },
                _middleChild: {
                    borderRadius: 0,
                    marginLeft: '-1px'
                },
                _lastChild: {
                    borderTopLeftRadius: 0,
                    borderBottomLeftRadius: 0,
                    marginLeft: '-1px'
                }
            },
            appearances: {},
            sizes: {}
        },
        Heading: {
            baseStyle: {
                color: '#234361',
                fontFamily: '"SF UI Display", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                fontWeight: 500
            },
            appearances: {},
            sizes: {
                '100': {
                    fontSize: '11px',
                    fontWeight: 400,
                    textTransform: 'uppercase',
                    lineHeight: '16px',
                    letterSpacing: '0.6px',
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                    color: '#66788A'
                },
                '200': {
                    fontSize: '12px',
                    fontWeight: 600,
                    lineHeight: '16px',
                    letterSpacing: '0',
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                    color: '#66788A'
                },
                '300': {
                    fontSize: '12px',
                    fontWeight: 600,
                    lineHeight: '16px',
                    letterSpacing: '0',
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"'
                },
                '400': {
                    fontSize: '14px',
                    fontWeight: 600,
                    lineHeight: '18px',
                    letterSpacing: '-0.05px',
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"'
                },
                '500': {
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                    fontSize: '16px',
                    letterSpacing: '-0.05px',
                    lineHeight: '20px'
                },
                '600': {
                    fontSize: '20px',
                    lineHeight: '24px',
                    letterSpacing: '-0.07px'
                },
                '700': {
                    fontSize: '24px',
                    lineHeight: '24px',
                    letterSpacing: '-0.07px'
                },
                '800': {
                    fontSize: '29px',
                    lineHeight: '32px',
                    letterSpacing: '-0.2px'
                },
                '900': {
                    fontSize: '35px',
                    lineHeight: '40px',
                    letterSpacing: '-0.2px'
                }
            }
        },
        Icon: {
            appearances: {},
            sizes: {}
        },
        InlineAlert: {
            baseStyle: {
                color: '#425A70'
            },
            appearances: {},
            sizes: {}
        },
        Input: {
            baseStyle: {
                borderRadius: '3px',
                lineHeight: '18px',
                color: '#425A70',
                fontSize: '12px',
                paddingX: 10,
                _placeholder: {
                    color: 'rgba(67, 90, 111, 0.47)'
                },
                _disabled: {
                    cursor: 'not-allowed'
                },
                _focus: {
                    zIndex: 2
                }
            },
            appearances: {
                default: {
                    backgroundColor: 'white',
                    _invalid: {},
                    _focus: {},
                    _disabled: {
                        backgroundColor: 'rgba(67, 90, 111, 0.06)'
                    }
                },
                neutral: {
                    backgroundColor: 'rgba(67, 90, 111, 0.06)',
                    _invalid: {},
                    _focus: {
                        backgroundColor: 'white'
                    },
                    _disabled: {}
                },
                none: {
                    backgroundColor: 'white',
                    _disabled: {
                        backgroundColor: '#F5F6F7'
                    }
                }
            },
            sizes: {
                small: {
                    height: 24
                },
                medium: {
                    height: 32
                },
                large: {
                    height: 40,
                    lineHeight: '20px'
                }
            }
        },
        Label: {
            baseStyle: {
                color: '#234361',
                fontFamily: '"SF UI Display", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                fontWeight: 500
            },
            appearances: {},
            sizes: {
                '100': {
                    fontSize: '11px',
                    fontWeight: 400,
                    textTransform: 'uppercase',
                    lineHeight: '16px',
                    letterSpacing: '0.6px',
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                    color: '#66788A'
                },
                '200': {
                    fontSize: '12px',
                    fontWeight: 600,
                    lineHeight: '16px',
                    letterSpacing: '0',
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                    color: '#66788A'
                },
                '300': {
                    fontSize: '12px',
                    fontWeight: 600,
                    lineHeight: '16px',
                    letterSpacing: '0',
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"'
                },
                '400': {
                    fontSize: '14px',
                    fontWeight: 600,
                    lineHeight: '18px',
                    letterSpacing: '-0.05px',
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"'
                },
                '500': {
                    fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                    fontSize: '16px',
                    letterSpacing: '-0.05px',
                    lineHeight: '20px'
                },
                '600': {
                    fontSize: '20px',
                    lineHeight: '24px',
                    letterSpacing: '-0.07px'
                },
                '700': {
                    fontSize: '24px',
                    lineHeight: '24px',
                    letterSpacing: '-0.07px'
                },
                '800': {
                    fontSize: '29px',
                    lineHeight: '32px',
                    letterSpacing: '-0.2px'
                },
                '900': {
                    fontSize: '35px',
                    lineHeight: '40px',
                    letterSpacing: '-0.2px'
                }
            }
        },
        List: {
            baseStyle: {},
            appearances: {},
            sizes: {}
        },
        Link: {
            baseStyle: {
                _hover: {},
                _active: {},
                _focus: {}
            },
            appearances: {},
            sizes: {}
        },
        MenuItem: {
            baseStyle: {
                outline: 'none',
                textDecoration: 'none',
                _isSelectable: {
                    cursor: 'pointer'
                },
                _disabled: {
                    cursor: 'not-allowed',
                    pointerEvents: 'none'
                }
            },
            appearances: {
                default: {
                    backgroundColor: 'white',
                    _hover: {
                        backgroundColor: '#F9F9FB'
                    },
                    _focus: {
                        backgroundColor: '#F9F9FB'
                    },
                    _active: {
                        backgroundColor: '#f7f9fd'
                    },
                    _current: {
                        backgroundColor: '#f7f9fd'
                    }
                }
            }
        },
        Option: {
            baseStyle: {
                outline: 'none',
                textDecoration: 'none',
                display: 'flex',
                position: 'relative',
                backgroundColor: 'white',
                _before: {
                    content: '""',
                    position: 'absolute',
                    left: 0,
                    top: 0,
                    bottom: 0,
                    width: 2,
                    backgroundColor: '#1070ca',
                    transition: '0.25s',
                    transformOrigin: 'left center',
                    transform: 'scaleX(0)'
                },
                _isSelectable: {
                    cursor: 'pointer'
                },
                _hover: {
                    backgroundColor: '#F9F9FB'
                },
                _focus: {
                    backgroundColor: '#F9F9FB'
                },
                _active: {
                    backgroundColor: '#f7f9fd'
                },
                _selected: {
                    backgroundColor: '#f7f9fd',
                    ' span': {
                        color: '#1070ca'
                    },
                    '&:before': {
                        transform: 'scaleX(1)'
                    }
                },
                _disabled: {
                    opacity: 0.5,
                    pointerEvents: 'none',
                    cursor: 'not-allowed'
                }
            }
        },
        Pane: {
            appearances: {},
            sizes: {}
        },
        Paragraph: {
            baseStyle: {
                marginTop: 0,
                marginBottom: 0
            },
            appearances: {},
            sizes: {
                '300': {
                    fontSize: '12px',
                    fontWeight: 400,
                    lineHeight: '18px',
                    letterSpacing: '0'
                },
                '400': {
                    fontSize: '14px',
                    fontWeight: 400,
                    lineHeight: '20px',
                    letterSpacing: '-0.05px'
                },
                '500': {
                    fontSize: '16px',
                    fontWeight: 400,
                    lineHeight: '24px',
                    letterSpacing: '-0.05px'
                },
                '600': {
                    fontSize: '20px',
                    fontWeight: 400,
                    lineHeight: '24px',
                    letterSpacing: '-0.07px'
                },
                small: {
                    fontSize: '12px',
                    fontWeight: 400,
                    lineHeight: '18px',
                    letterSpacing: '0'
                },
                medium: {
                    fontSize: '14px',
                    fontWeight: 400,
                    lineHeight: '20px',
                    letterSpacing: '-0.05px'
                },
                large: {
                    fontSize: '16px',
                    fontWeight: 400,
                    lineHeight: '24px',
                    letterSpacing: '-0.05px'
                }
            }
        },
        Radio: {
            baseStyle: {},
            appearances: {
                default: {
                    _base: {
                        color: 'transparent'
                    },
                    _disabled: {
                        cursor: 'not-allowed',
                        background: 'rgba(67, 90, 111, 0.06)'
                    },
                    _hover: {},
                    _focus: {},
                    _active: {
                        background: 'rgba(16, 112, 202, 0.09)'
                    },
                    _checked: {
                        color: 'white',
                        background: 'linear-gradient(to bottom, #0788DE, #116AB8)'
                    },
                    _checkedHover: {
                        color: 'white',
                        background: 'linear-gradient(to bottom, #0679c5, #0f5da1)'
                    },
                    _checkedDisabled: {
                        color: 'rgba(67, 90, 111, 0.47)'
                    },
                    _checkedActive: {
                        color: 'white',
                        background: 'linear-gradient(to bottom, #0f5da1, #0f5da1)'
                    }
                }
            },
            sizes: {}
        },
        Select: {
            baseStyle: {
                fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                border: 'none',
                borderRadius: '3px'
            },
            appearances: {
                default: {
                    color: 'rgba(67, 90, 111, 0.81)',
                    backgroundColor: 'white',
                    backgroundImage: 'linear-gradient(to bottom, #FFFFFF, #F4F5F7)',
                    boxShadow: 'inset 0 0 0 1px rgba(67, 90, 111, 0.14), inset 0 -1px 1px 0 rgba(67, 90, 111, 0.06)',
                    _disabled: {
                        opacity: 0.8,
                        backgroundImage: 'none',
                        backgroundColor: 'rgba(67, 90, 111, 0.06)',
                        boxShadow: 'none',
                        color: 'rgba(67, 90, 111, 0.7)',
                        pointerEvents: 'none'
                    },
                    _hover: {
                        backgroundImage: 'linear-gradient(to bottom, #FAFBFB, #EAECEE)'
                    },
                    _active: {
                        backgroundImage: 'none',
                        backgroundColor: 'rgba(16, 112, 202, 0.09)',
                        boxShadow: 'inset 0 0 0 1px rgba(67, 90, 111, 0.14), inset 0 1px 1px 0 rgba(67, 90, 111, 0.06)'
                    },
                    _focus: {
                        boxShadow: '0 0 0 3px rgba(16, 112, 202, 0.14), inset 0 0 0 1px rgba(67, 90, 111, 0.3), inset 0 -1px 1px 0 rgba(67, 90, 111, 0.14)'
                    }
                }
            },
            sizes: {
                small: {
                    height: 24,
                    minWidth: 24,
                    fontSize: '12px',
                    lineHeight: '16px'
                },
                medium: {
                    height: 32,
                    minWidth: 32,
                    fontSize: '12px',
                    lineHeight: '16px'
                },
                large: {
                    height: 40,
                    minWidth: 40,
                    fontSize: '14px',
                    lineHeight: '20px'
                }
            }
        },
        Spinner: {
            baseStyle: {
                color: 'rgba(67, 90, 111, 0.47)'
            },
            appearances: {},
            sizes: {
                small: {
                    width: 32,
                    height: 32
                },
                medium: {
                    width: 40,
                    height: 40
                },
                large: {
                    width: 48,
                    height: 48
                }
            }
        },
        Switch: {
            baseStyle: {},
            appearances: {
                default: {
                    _base: {
                        color: 'white',
                        backgroundColor: 'rgba(67, 90, 111, 0.3)'
                    },
                    _disabled: {
                        opacity: 0.5,
                        backgroundImage: 'none'
                    },
                    _hover: {
                        backgroundColor: 'rgba(67, 90, 111, 0.3)'
                    },
                    _active: {
                        backgroundColor: 'rgba(67, 90, 111, 0.47)'
                    },
                    _focus: {},
                    _checked: {
                        backgroundColor: '#3d8bd4',
                        color: 'white'
                    },
                    _checkedHover: {
                        backgroundColor: '#3d8bd4',
                        color: 'white'
                    },
                    _checkedActive: {
                        backgroundColor: '#1070ca',
                        color: 'white'
                    },
                    _checkedDisabled: {}
                }
            },
            sizes: {}
        },
        Tab: {
            baseStyle: {
                fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                fontWeight: 500,
                padding: '8px',
                borderRadius: '3px',
                color: '#425A70',
                _hover: {
                    backgroundColor: 'rgba(67, 90, 111, 0.06)'
                },
                _active: {
                    backgroundColor: 'rgba(67, 90, 111, 0.09)'
                },
                _current: {
                    color: '#1070ca',
                    backgroundColor: 'rgba(16, 112, 202, 0.09)'
                },
                _focus: {
                    boxShadow: '0 0 0 3px rgba(16, 112, 202, 0.14)'
                },
                _disabled: {
                    pointerEvents: 'none',
                    cursor: 'not-allowed',
                    color: 'rgba(67, 90, 111, 0.7)',
                    '&[aria-current="page"], &[aria-selected="true"]': {
                        backgroundColor: 'rgba(67, 90, 111, 0.06)'
                    }
                }
            }
        },
        Table: {
            baseStyle: {},
            appearances: {},
            sizes: {}
        },
        TableCell: {
            baseStyle: {
                paddingX: 12
            },
            appearances: {
                default: {
                    _focus: {
                        outline: 'none',
                        backgroundColor: 'rgba(16, 112, 202, 0.06)'
                    }
                }
            },
            sizes: {}
        },
        TableHead: {
            baseStyle: {
                borderBottom: 'default',
                background: '#F5F6F7',
                height: '32px',
                fontSize: '12px',
                fontWeight: 500,
                lineHeight: '16px',
                letterSpacing: '0',
                fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                color: '#425A70'
            },
            appearances: {},
            sizes: {}
        },
        TableRow: {
            baseStyle: {
                outline: 'none',
                textDecoration: 'none',
                height: 48,
                _isSelectable: {
                    cursor: 'pointer'
                }
            },
            appearances: {
                default: {
                    _hover: {},
                    _focus: {},
                    _active: {},
                    _current: {}
                }
            }
        },
        TagInput: {
            baseStyle: {
                paddingY: '2px',
                paddingX: '4px',
                backgroundColor: 'white',
                borderRadius: '3px'
            },
            appearances: {
                default: {
                    backgroundColor: 'white',
                    _focused: {
                        zIndex: 2
                    },
                    _invalid: {},
                    _disabled: {
                        backgroundColor: '#F5F6F7'
                    }
                }
            },
            sizes: {}
        },
        Text: {
            baseStyle: {},
            appearances: {},
            sizes: {
                '300': {
                    fontSize: '12px',
                    fontWeight: 400,
                    lineHeight: '16px',
                    letterSpacing: '0'
                },
                '400': {
                    fontSize: '14px',
                    fontWeight: 400,
                    lineHeight: '20px',
                    letterSpacing: '-0.05px'
                },
                '500': {
                    fontSize: '16px',
                    fontWeight: 400,
                    lineHeight: '20px',
                    letterSpacing: '-0.05px'
                },
                '600': {
                    fontSize: '20px',
                    fontWeight: 400,
                    lineHeight: '24px',
                    letterSpacing: '-0.07px'
                },
                small: {
                    fontSize: '12px',
                    fontWeight: 400,
                    lineHeight: '16px',
                    letterSpacing: '0'
                },
                medium: {
                    fontSize: '14px',
                    fontWeight: 400,
                    lineHeight: '20px',
                    letterSpacing: '-0.05px'
                },
                large: {
                    fontSize: '16px',
                    fontWeight: 400,
                    lineHeight: '20px',
                    letterSpacing: '-0.05px'
                }
            }
        },
        TextDropdownButton: {
            baseStyle: {
                fontFamily: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
                backgroundColor: 'transparent',
                borderRadius: '3px',
                paddingX: 4,
                marginX: -4,
                paddingY: 2,
                marginY: -2,
                color: '#425A70',
                _disabled: {
                    cursor: 'not-allowed',
                    pointerEvents: 'none'
                },
                _focus: {}
            },
            appearances: {},
            sizes: {
                small: {
                    fontSize: '12px',
                    lineHeight: '16px'
                },
                medium: {
                    fontSize: '12px',
                    lineHeight: '16px'
                },
                large: {
                    fontSize: '14px',
                    lineHeight: '20px'
                }
            }
        },
        Tooltip: {
            baseStyle: {
                paddingX: 8,
                paddingY: 4,
                borderRadius: '3px',
                maxWidth: 240,
                elevation: '0 0 1px rgba(67, 90, 111, 0.3), 0 8px 10px -4px rgba(67, 90, 111, 0.47)'
            },
            appearances: {
                card: {
                    backgroundColor: 'white'
                },
                default: {
                    color: 'white',
                    backgroundColor: '#425A70'
                }
            },
            sizes: {}
        }
    }
};
const transformer = (_file, _api) => {
    return `export const classicTheme = ${JSON.stringify(classicTheme, undefined, 4)}`;
};
exports.default = transformer;
