"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.once = void 0;
/**
 * Ensures a function is only called once. Subsequent calls will return the initial result.
 */
const once = (fn) => {
    let called = false;
    let result;
    return function (...args) {
        if (called) {
            return result;
        }
        result = fn.apply(this, args);
        called = true;
        return result;
    };
};
exports.once = once;
